==> vradi-entities-0.4.0-sources.jar: com/jurismarches/vradi/entities/FormLink.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyTreeNode;
import org.nuiton.wikitty.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.WikittyTreeNodeImpl;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface FormLink extends BusinessEntity {     String EXT_FORMLINK = "FormLink";
     String FIELD_FORMLINK_NAME = "name";
     String FQ_FIELD_FORMLINK_NAME = EXT_FORMLINK + ".name";
     String FIELD_FORMLINK_TYPE = "type";
     String FQ_FIELD_FORMLINK_TYPE = EXT_FORMLINK + ".type";
     String FIELD_FORMLINK_FROMFORM = "fromForm";
     String FQ_FIELD_FORMLINK_FROMFORM = EXT_FORMLINK + ".fromForm";
     String FIELD_FORMLINK_TOFORM = "toForm";
     String FQ_FIELD_FORMLINK_TOFORM = EXT_FORMLINK + ".toForm";
    /**
     * getName :
     * @return String 
     */

     String getName();

    /**
     * setName :
     * @param name 
     */

     void setName(String name);

    /**
     * getType :
     * @return int 
     */

     int getType();

    /**
     * setType :
     * @param type 
     */

     void setType(int type);

    /**
     * getFromForm :
     * @return String 
     */

     String getFromForm();

    /**
     * setFromForm :
     * @param fromForm 
     */

     void setFromForm(String fromForm);

    /**
     * getToForm :
     * @return String 
     */

     String getToForm();

    /**
     * setToForm :
     * @param toForm 
     */

     void setToForm(String toForm);


} //FormLink

==> vradi-entities-0.5.1-sources.jar: com/jurismarches/vradi/entities/FormLink.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;


public interface FormLink extends BusinessEntity {     String EXT_FORMLINK = "FormLink";
     String FIELD_FORMLINK_NAME = "name";
     String FQ_FIELD_FORMLINK_NAME = EXT_FORMLINK + ".name";
     String FIELD_FORMLINK_TYPE = "type";
     String FQ_FIELD_FORMLINK_TYPE = EXT_FORMLINK + ".type";
     String FIELD_FORMLINK_FROMFORM = "fromForm";
     String FQ_FIELD_FORMLINK_FROMFORM = EXT_FORMLINK + ".fromForm";
     String FIELD_FORMLINK_TOFORM = "toForm";
     String FQ_FIELD_FORMLINK_TOFORM = EXT_FORMLINK + ".toForm";
    /**
     * getName :
     * @return String 
     */

     String getName();

    /**
     * setName :
     * @param name 
     */

     void setName(String name);

    /**
     * getType :
     * @return int 
     */

     int getType();

    /**
     * setType :
     * @param type 
     */

     void setType(int type);

    /**
     * getFromForm :
     * @return String 
     */

     String getFromForm();

    /**
     * setFromForm :
     * @param fromForm 
     */

     void setFromForm(String fromForm);

    /**
     * getToForm :
     * @return String 
     */

     String getToForm();

    /**
     * setToForm :
     * @param toForm 
     */

     void setToForm(String toForm);


} //FormLink
